<?php namespace EscapeWork\Manager\Downloads\Commands;

use EscapeWork\Manager\Downloads\Seeds\DownloadTableSeeder;
use EscapeWork\Manager\Downloads\Seeds\MediaSeeder;
use Illuminate\Console\Command;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;
use File;

class ConfigureCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager-downloads:configure';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Migrations, Seeds, plugins e tudo que precisar ser configurado.';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function fire()
    {
        $this->comment('--- Configurando escapework/manager-downloads ---');

        # migrations
        $this->comment('Realizando as migrações do escapework/manager-downloads...');
        $this->call('migrate', array('--package' => 'escapework/manager-downloads'));

        # seed
        $this->comment('Fazendo os seeds...');

        $seeder = new DownloadTableSeeder();
        $seeder->setContainer($this->laravel)->setCommand($this)->run();

        $seeder = new MediaSeeder();
        $seeder->setContainer($this->laravel)->setCommand($this)->run();

        $this->info('escapework/manager-downloads seeded!');

        # public folder
        $path = public_path().'/files/downloads';

        if (! File::exists($path)) {
            File::makeDirectory($path, 0773);
            $this->info('diretório public/files/downloads criado!');
        }

        $this->comment('--- escapework/manager-downloads configurado ---');
    }

    /**
     * Get the console command arguments.
     *
     * @return array
     */
    protected function getArguments()
    {
        return array();
    }

    /**
     * Get the console command options.
     *
     * @return array
     */
    protected function getOptions()
    {
        return array();
    }

}
