<?php namespace EscapeWork\Manager\Downloads\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Downloads\Repositories\DownloadCategory\DownloadCategoryRepository;
use EscapeWork\Manager\Downloads\Models\DownloadCategory;
use View;
use Input;
use Redirect;
use Response;
use Request;
use Config;
use Msg;

class DownloadCategoriesController extends ManagerController
{
    public function __construct(DownloadCategoryRepository $downloadCategory)
    {
        $this->downloadCategory = $downloadCategory;

        # filters
        $this->enableDefaultFilters('downloads');
    }

    public function index()
    {
        $view = View::make('manager-downloads::downloads.categories.index');
        $view->downloadCategories = $this->downloadCategory->paginate(20);
        return $view;
    }

    public function create()
    {
        $this->downloadCategory->fill(Input::old());

        $view                   = View::make('manager-downloads::downloads.categories.form');
        $view->downloadCategory = $this->downloadCategory;
        $view->edit             = false;

        return $view;
    }

    public function store()
    {
        $this->downloadCategory->fill(Input::all());

        if (! $this->downloadCategory->validate()) {
            return Redirect::route('manager.downloads.categories.create')
                        ->withInput()
                        ->withErrors($this->downloadCategory->getValidationErrors());
        }

        $this->downloadCategory->save();

        return Redirect::route('manager.downloads.categories.index')->with('message', 'A categoria <strong>' . $this->downloadCategory->title . '</strong> foi inserida com sucesso!');
    }

    public function edit($id)
    {
        $this->downloadCategory = $this->downloadCategory->findOrFail($id);

        Msg::setInfo('Editando a categoria <strong>' . $this->downloadCategory->title . '</strong>');

        $view                    = View::make('manager-downloads::downloads.categories.form');
        $view->downloadCategory  = $this->downloadCategory;
        $view->edit              = true;

        return $view;
    }

    public function update($id)
    {
        $this->downloadCategory = $this->downloadCategory->findOrFail($id);
        $this->downloadCategory->fill(Input::all());

        if (! $this->downloadCategory->validate()) {
            return Redirect::route('manager.downloads.categories.edit', array($this->downloadCategory->id))
                    ->withInput()
                    ->withErrors($this->downloadCategory->getValidationErrors());
        }

        $this->downloadCategory->save();

        return Redirect::route('manager.downloads.categories.index')
                ->with('message', 'A categoria <strong>'.$this->downloadCategory->title.'</strong> foi editada com sucesso!');
    }

    public function destroy($id)
    {
        $this->downloadCategory = $this->downloadCategory->findOrFail($id);
        $this->downloadCategory->destroy($id);

        return Redirect::route('manager.downloads.categories.index')
                ->with('message', 'A categoria <strong>'.$this->downloadCategory->title.'</strong> foi excluída com sucesso!');
    }
}
