<?php namespace EscapeWork\Manager\Downloads\Providers;

use EscapeWork\Manager\Downloads\Commands\ConfigureCommand;
use Illuminate\Support\ServiceProvider;

class ManagerDownloadsServiceProvider extends ServiceProvider
{

    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        $this->package('escapework/manager-downloads', 'manager-downloads', realpath(__DIR__ . '/../../../../'));

        include_once(__DIR__ . '/../../../../routes.php');
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerCommands();
        $this->bindRepositories();

        $this->app['config']->set('manager::packages.manager-downloads', 'manager-downloads');
    }

    protected function bindRepositories()
    {
        $this->app->bind('EscapeWork\Manager\Downloads\Repositories\Download\DownloadRepository', 'EscapeWork\Manager\Downloads\Repositories\Download\EloquentDownloadRepository');
        $this->app->bind('EscapeWork\Manager\Downloads\Repositories\DownloadCategory\DownloadCategoryRepository', 'EscapeWork\Manager\Downloads\Repositories\DownloadCategory\EloquentDownloadCategoryRepository');
    }

    protected function registerCommands()
    {
        $this->app['command.manager.downloads.configure'] = $this->app->share(function($app)
        {
            return new ConfigureCommand;
        });

        $this->commands('command.manager.downloads.configure');
    }

    public function provides()
    {
        return array('command.manager.downloads.configure');
    }

}
