<?php namespace EscapeWork\Manager\Downloads\Repositories\Download;

use EscapeWork\Manager\Repositories\BaseEloquentRepository;
use EscapeWork\Manager\Downloads\Models\Download;
use EscapeWork\Manager\Medias\Helpers\ImageUploader;
use Str;

class EloquentDownloadRepository extends BaseEloquentRepository implements DownloadRepository
{
    public function __construct(Download $download)
    {
        $this->model = $download;
    }

    protected $dir = 'files/downloads/';

    /**
     * Formata o nome do arquivo
     */
    public function formatFileName($file)
    {
        $string  = explode('.', $file->getClientOriginalName());

        unset($string[count($string) - 1]);

        $slug = Str::slug(implode('.', $string)). '.' . $file->getClientOriginalExtension();

        while (is_file($this->getDir() . $slug)) {
            $slug = '_' . $slug;
        }

        return $slug;
    }

    /**
     * Fazendo upload da thumb
     */
    public function uploadThumb($thumb, $update = false)
    {
        $imageUploader = new ImageUploader(public_path().'/files/downloads', get_class($this->model));

        if ($imageUploader->upload($thumb, $update, $this->model->thumb)) {
            $this->model->thumb = $imageUploader->filename;

            return true;
        }
    }

    /**
     * Diretorio do arquivos para download
     */
    protected function getDir()
    {
        return public_path() . '/' . $this->dir;
    }

    /**
     * Deleta um determinado arquivo do diretorio.
     */
    public function deleteFile($filename)
    {
        $file = $this->getDir() . '/' . $filename;

        if (is_file($file)) {
            unlink($file);
        }
    }

    /**
     * Upload de arquivo
     */
    public function uploadFile($file)
    {
        $filename = $this->formatFileName($file);

        while (is_file($this->getDir() . $filename)) {
            $filename = '_' . $filename;
        }

        $file->move($this->getDir(), $filename);
    }

    /**
     *
     */
    public function getDownloadsByIdCategory($categoryId)
    {
        return $this->where('category_id', '=', $categoryId)
                    ->get();
    }
}
